@@ -182,7 +182,7 @@ class Seti():
         }
         CREATE_RECHARGER_URL = "create-recharger"
         encode_data = self.sign_data(data_create_recharger)
-        return ResponseCreateTransaction(self.send_request(data_create_recharger,encode_data,CREATE_RECHARGER_URL))
+        return ResponseCreatePayment(self.send_request(data_create_recharger,encode_data,CREATE_RECHARGER_URL))
     
     # Dispersion
     
